@@ -71,6 +71,10 @@ TpSession::TpSession(QString cmname,bool synchronous)
     Tp::enableDebug(false);
     Tp::enableWarnings(false);
 
+    QProcessEnvironment env;
+    tpsdebug=env.systemEnvironment().contains("TPSESSION_DEBUG");
+    if(tpsdebug) qDebug() << "Tpsession debug:" << tpsDebug();
+
     mAM = Tp::AccountManager::create();
     reqCm=cmname;
     sync=synchronous;
@@ -87,6 +91,7 @@ TpSession::TpSession(QString cmname,bool synchronous)
 
 }
 TpSession* TpSession::instancePtr=NULL;
+bool TpSession::tpsdebug=false;
 /**
  * Returns pointer to TpSession singleton. If there is not yet TpSession Object, creates it with "Ring" connection manager as default
  *
@@ -99,9 +104,15 @@ TpSession* TpSession::instance(bool synchronous)
     return instancePtr;
 };
 
+bool TpSession::tpsDebug()
+{
+    return tpsdebug;
+}
+
 void TpSession::onAMReady(Tp::PendingOperation *op)
 {
- qDebug() << "TpSession::onAMReady";
+ Q_UNUSED(op);
+  // qDebug() << "TpSession::onAMReady";
  TpSessionAccount *tpacc;
 
    foreach (const QString &path, mAM->allAccountPaths()) {
@@ -124,7 +135,7 @@ void TpSession::onAccountCreated(const QString &path)
 
 void TpSession::onAccountReady(TpSessionAccount *tpacc)
 {
-  qDebug() << "TpSession::onAccountReady:Account " << tpacc->acc->cmName() << "is Ready sync=" << sync << "waiting:" << reqCm;
+  //qDebug() << "TpSession::onAccountReady:Account " << tpacc->acc->cmName() << "is Ready sync=" << sync << "waiting:" << reqCm;
   connect(tpacc,SIGNAL(messageReceived(const Tp::ReceivedMessage &,TpSessionAccount *)),
                   SLOT(onMessageReceived(const Tp::ReceivedMessage &,TpSessionAccount *)));
   if(!reqCm.isEmpty() && tpacc->acc->cmName()==reqCm) {
@@ -140,7 +151,7 @@ void TpSession::onAccountReady(TpSessionAccount *tpacc)
 
 void TpSession::onMessageReceived(const Tp::ReceivedMessage &msg,TpSessionAccount *acc)
 {
-    qDebug() << "TestProg::onMessageReceived " << msg.text() << "from " << msg.sender()->id();
+  //    qDebug() << "TestProg::onMessageReceived " << msg.text() << "from " << msg.sender()->id();
     emit messageReceived(msg,acc);
 }
 
@@ -164,10 +175,10 @@ void TpSession::sendMessageToAddress(QString connectionMgr,QString address,QStri
  */
 TpSessionAccount* TpSession::getAccount(const  QString cm,QString protocol)
 {
- qDebug() << "TpSession::getAccount" << cm << " " << protocol;
+  // qDebug() << "TpSession::getAccount" << cm << " " << protocol;
  foreach (TpSessionAccount *tpacc, accounts) {
    if((!cm.isEmpty()  && ((tpacc->acc->cmName()==cm) || (tpacc->acc->uniqueIdentifier()==cm))) || (!protocol.isEmpty() && tpacc->acc->protocol()==protocol)) {
-     qDebug() << "TpSession::getAccount found" << tpacc->acc->cmName() << " " << tpacc->acc->protocol() << " " << tpacc->acc->uniqueIdentifier();
+     //     qDebug() << "TpSession::getAccount found" << tpacc->acc->cmName() << " " << tpacc->acc->protocol() << " " << tpacc->acc->uniqueIdentifier();
      return tpacc;
      }
  }
@@ -177,7 +188,7 @@ TpSessionAccount* TpSession::getAccount(const  QString cm,QString protocol)
 void TpSession::createObserver()
 {
 
-    qDebug() << __PRETTY_FUNCTION__ ;
+      qDebug() << __PRETTY_FUNCTION__ ;
 
     registrar = Tp::ClientRegistrar::create();
 
@@ -201,8 +212,7 @@ void TpSession::createObserver()
     bool registered = registrar->registerClient(
       Tp::AbstractClientPtr::dynamicCast(Tp::SharedPtr<TpSessionObserver>(observer)),
       "TpSessionChannelObserver");
-
-        qDebug() << "TpSession::createObserver" << (registered ? "started" : "failed");
+    qDebug() << "TpSession::createObserver" << (registered ? "started" : "failed");
 
 }
 
@@ -212,6 +222,8 @@ void TpSession::createChannelListener(const QString &channelType,
                                    const Tp::AccountPtr &account,
                                    const Tp::ChannelPtr &channel)
 {
+    Q_UNUSED(context);
+    Q_UNUSED(account);
     qDebug() << "TpSession::createChannelListener";
 
     QString channelObjectPath = channel->objectPath();
